var NAVTREEINDEX0 =
{
"LREADME.html":[10],
"LREADME.html#adding-a-new-test-data-file":[10,0,2,3],
"LREADME.html#additional-test-data":[10,0,2,4],
"LREADME.html#autotoc_md0":[10,0],
"LREADME.html#autotoc_md1":[10,0,0],
"LREADME.html#autotoc_md2":[10,0,2,0,0],
"LREADME.html#autotoc_md3":[10,0,2,0,1],
"LREADME.html#autotoc_md4":[10,0,2,0,2],
"LREADME.html#autotoc_md5":[10,0,2,5,0],
"LREADME.html#autotoc_md6":[10,0,2,5,1],
"LREADME.html#basic-build":[10,0,1,2],
"LREADME.html#bug-reports":[10,0,6],
"LREADME.html#build-with-vmaf":[10,0,1,12],
"LREADME.html#building-the-library-and-applications":[10,0,1],
"LREADME.html#coding-style":[10,0,3],
"LREADME.html#commit-message-hook":[10,0,4,3],
"LREADME.html#configuration-options":[10,0,1,3],
"LREADME.html#contributor-agreement":[10,0,4,1],
"LREADME.html#cross-compiling":[10,0,1,6],
"LREADME.html#debugging":[10,0,1,5],
"LREADME.html#downloading-the-test-data":[10,0,2,2],
"LREADME.html#dylib-builds":[10,0,1,4],
"LREADME.html#emscripten-builds":[10,0,1,10],
"LREADME.html#extra-build-flags":[10,0,1,11],
"LREADME.html#get-the-code":[10,0,1,1],
"LREADME.html#ide-hosted-tests":[10,0,2,1],
"LREADME.html#incorporating-reviewer-comments":[10,0,4,5],
"LREADME.html#login-cookie":[10,0,4,0],
"LREADME.html#microsoft-visual-studio-builds":[10,0,1,8],
"LREADME.html#prerequisites":[10,0,1,0],
"LREADME.html#sanitizers":[10,0,1,7],
"LREADME.html#sharded-testing":[10,0,2,5],
"LREADME.html#submitting-patches":[10,0,4],
"LREADME.html#submitting-your-change":[10,0,4,6],
"LREADME.html#support":[10,0,5],
"LREADME.html#testing-basics":[10,0,2,0],
"LREADME.html#testing-the-av1-codec":[10,0,2],
"LREADME.html#testing-your-code":[10,0,4,2],
"LREADME.html#upload-your-change":[10,0,4,4],
"LREADME.html#viewing-the-status-of-uploaded-changes":[10,0,4,7],
"LREADME.html#xcode-builds":[10,0,1,9],
"annotated.html":[13,0],
"aom_8h.html":[14,0,0,0],
"aom_8h_source.html":[14,0,0,0],
"aom__codec_8h.html":[14,0,0,1],
"aom__codec_8h_source.html":[14,0,0,1],
"aom__decoder_8h.html":[14,0,0,2],
"aom__decoder_8h_source.html":[14,0,0,2],
"aom__encoder_8h.html":[14,0,0,3],
"aom__encoder_8h.html#a3ec4904ea175471a03d10705f384d07c":[14,0,0,3,7],
"aom__encoder_8h.html#a446aae868ff07f3971d9e84b6602a890":[14,0,0,3,8],
"aom__encoder_8h.html#ab96879b5e659b5d1c390253f4c3658b2":[14,0,0,3,9],
"aom__encoder_8h_source.html":[14,0,0,3],
"aom__frame__buffer_8h.html":[14,0,0,4],
"aom__frame__buffer_8h.html#a01fdfbbc9be8b320437a49d3de07814d":[14,0,0,4,4],
"aom__frame__buffer_8h.html#a1803cd0766dc297d88172f174fbb6ab5":[14,0,0,4,5],
"aom__frame__buffer_8h.html#a9470ef667d6ce967e93d9e528d523919":[14,0,0,4,1],
"aom__frame__buffer_8h.html#aa61b60e9ccca38ff4aef31d5c684c236":[14,0,0,4,3],
"aom__frame__buffer_8h.html#ae4e6b2da21b594cbea52e2927d1efbeb":[14,0,0,4,2],
"aom__frame__buffer_8h_source.html":[14,0,0,4],
"aom__image_8h.html":[14,0,0,5],
"aom__image_8h.html#a07982736cb1c840edb4e2f89b0fe71db":[14,0,0,5,26],
"aom__image_8h.html#a07982736cb1c840edb4e2f89b0fe71dba180079448d81295c837817887e736d28":[14,0,0,5,26,1],
"aom__image_8h.html#a07982736cb1c840edb4e2f89b0fe71dba2c7b3fb1f65477c56eaa649a9160f308":[14,0,0,5,26,2],
"aom__image_8h.html#a07982736cb1c840edb4e2f89b0fe71dba866c03f3337047d3beafa2e8140b2c30":[14,0,0,5,26,0],
"aom__image_8h.html#a0845e9194541329c0f77b4bd6a38cc7c":[14,0,0,5,8],
"aom__image_8h.html#a0c5fe4946bdc15a5fe6bedc7ee96d400":[14,0,0,5,30],
"aom__image_8h.html#a0fb3260583f3f412a553ea8315ff26e0":[14,0,0,5,16],
"aom__image_8h.html#a10590253ef3dbde7e93ed5d4b4e0e73b":[14,0,0,5,25],
"aom__image_8h.html#a10590253ef3dbde7e93ed5d4b4e0e73ba01ef7204c2234ef43acfd493d5e18c84":[14,0,0,5,25,2],
"aom__image_8h.html#a10590253ef3dbde7e93ed5d4b4e0e73ba7843506f3e28f720be0d4f03237fb48c":[14,0,0,5,25,0],
"aom__image_8h.html#a10590253ef3dbde7e93ed5d4b4e0e73baae9f183ca3336d18e21d180341d00a36":[14,0,0,5,25,3],
"aom__image_8h.html#a10590253ef3dbde7e93ed5d4b4e0e73baf95ced9b8288642205301cc51e0b55c6":[14,0,0,5,25,1],
"aom__image_8h.html#a1be1887a76e89f3a4f84ccb11dde025e":[14,0,0,5,6],
"aom__image_8h.html#a1fc7a318a190ffdadc723aca13e373cf":[14,0,0,5,31],
"aom__image_8h.html#a22d60e6e3af866e523788a6b1203c71c":[14,0,0,5,2],
"aom__image_8h.html#a260d525738419165f7840aef3f969303":[14,0,0,5,15],
"aom__image_8h.html#a2ad22076006b15cf809edcaa33f6d339":[14,0,0,5,7],
"aom__image_8h.html#a30655997e3fb79889ee23eb294cb1992":[14,0,0,5,22],
"aom__image_8h.html#a30655997e3fb79889ee23eb294cb1992a1ce5fbca5277266680d70bb7211646d6":[14,0,0,5,22,14],
"aom__image_8h.html#a30655997e3fb79889ee23eb294cb1992a2d10943cf211ebef4d149155b0ec2b1e":[14,0,0,5,22,19],
"aom__image_8h.html#a30655997e3fb79889ee23eb294cb1992a31c9111a24763c11ae11f17aab940783":[14,0,0,5,22,0],
"aom__image_8h.html#a30655997e3fb79889ee23eb294cb1992a356d6943d11d88e7a42370c1c698c214":[14,0,0,5,22,4],
"aom__image_8h.html#a30655997e3fb79889ee23eb294cb1992a3d7b83c425c539d1a36fb36e9aebf268":[14,0,0,5,22,18],
"aom__image_8h.html#a30655997e3fb79889ee23eb294cb1992a45df590313483af0c614708f346028c4":[14,0,0,5,22,17],
"aom__image_8h.html#a30655997e3fb79889ee23eb294cb1992a4f17a249c9791f5e8b0d22850d13842f":[14,0,0,5,22,3],
"aom__image_8h.html#a30655997e3fb79889ee23eb294cb1992a54ec8cfad46215d855696bafe371ffe1":[14,0,0,5,22,9],
"aom__image_8h.html#a30655997e3fb79889ee23eb294cb1992a57f92f410badf8a43b19df18edc9b8b9":[14,0,0,5,22,11],
"aom__image_8h.html#a30655997e3fb79889ee23eb294cb1992a5b51bfcf0f3779a7d907ac45ee4067a4":[14,0,0,5,22,6],
"aom__image_8h.html#a30655997e3fb79889ee23eb294cb1992a7a347c6d5605db0a6ee89cc81dec0b37":[14,0,0,5,22,5],
"aom__image_8h.html#a30655997e3fb79889ee23eb294cb1992a7d79c257042a5958bafa6b5ccfbd96cb":[14,0,0,5,22,10],
"aom__image_8h.html#a30655997e3fb79889ee23eb294cb1992a81a9e0af519cb43502caa899233f4c7e":[14,0,0,5,22,2],
"aom__image_8h.html#a30655997e3fb79889ee23eb294cb1992a94553e773e3d3fb005236ed70eeedfea":[14,0,0,5,22,13],
"aom__image_8h.html#a30655997e3fb79889ee23eb294cb1992a99ebdb0b1a35e0bf25808f851aa80a35":[14,0,0,5,22,8],
"aom__image_8h.html#a30655997e3fb79889ee23eb294cb1992ab48fdcc8c2c0350f6423b9c116c1876d":[14,0,0,5,22,16],
"aom__image_8h.html#a30655997e3fb79889ee23eb294cb1992ac3b5e95e3400830c334268fca69a1226":[14,0,0,5,22,7],
"aom__image_8h.html#a30655997e3fb79889ee23eb294cb1992ac60ca749a2d0ca1c860d82f0825a3e2d":[14,0,0,5,22,12],
"aom__image_8h.html#a30655997e3fb79889ee23eb294cb1992afcc74c6858aefc13c426dd6992198e75":[14,0,0,5,22,15],
"aom__image_8h.html#a30655997e3fb79889ee23eb294cb1992affe340e422646b7d70ef91edd6a8053c":[14,0,0,5,22,1],
"aom__image_8h.html#a314394a55ea489f1470ba5d1e977e0ec":[14,0,0,5,28],
"aom__image_8h.html#a32a43f20adb01d846af1925189c37495":[14,0,0,5,9],
"aom__image_8h.html#a3b66685dabbd9eee040d9a3989d52a12":[14,0,0,5,17],
"aom__image_8h.html#a3eddd2c7c36b77245582a230d3f8578f":[14,0,0,5,12],
"aom__image_8h.html#a5267ad095a088ece3499336812503cef":[14,0,0,5,21],
"aom__image_8h.html#a5267ad095a088ece3499336812503cefa0835a3af8e6ffc6df298b6e64f878431":[14,0,0,5,21,2],
"aom__image_8h.html#a5267ad095a088ece3499336812503cefa1a8b2e5694489121f80a406d9da25dfb":[14,0,0,5,21,7],
"aom__image_8h.html#a5267ad095a088ece3499336812503cefa227b6e4116ed0266af20b705aebaf661":[14,0,0,5,21,12],
"aom__image_8h.html#a5267ad095a088ece3499336812503cefa34a3459d4b145006614dfb428b9ebe8a":[14,0,0,5,21,15],
"aom__image_8h.html#a5267ad095a088ece3499336812503cefa3ce81eb125550ec2f11a58f183eeaee6":[14,0,0,5,21,6],
"aom__image_8h.html#a5267ad095a088ece3499336812503cefa53f592f9fef9c421db024f1c4697a908":[14,0,0,5,21,13],
"aom__image_8h.html#a5267ad095a088ece3499336812503cefa54d519c9ac0ca52ebda7caf736530e57":[14,0,0,5,21,11],
"aom__image_8h.html#a5267ad095a088ece3499336812503cefa5b57cb26f04f4df6585335129392d5e2":[14,0,0,5,21,4],
"aom__image_8h.html#a5267ad095a088ece3499336812503cefa6032cae72a729933a6a75e3b943a542c":[14,0,0,5,21,10],
"aom__image_8h.html#a5267ad095a088ece3499336812503cefa6bb95baf09cd6e1f3596b459712c592a":[14,0,0,5,21,9],
"aom__image_8h.html#a5267ad095a088ece3499336812503cefa8032bcfaf84734707ad00633145da35c":[14,0,0,5,21,0],
"aom__image_8h.html#a5267ad095a088ece3499336812503cefa8b33dc8483c16048c606d75d9f11e38a":[14,0,0,5,21,5],
"aom__image_8h.html#a5267ad095a088ece3499336812503cefa8dd6ba5106c22d149a233e73232aeb65":[14,0,0,5,21,8],
"aom__image_8h.html#a5267ad095a088ece3499336812503cefa9a2ebe055c0508a2a2f72b6c192fcce9":[14,0,0,5,21,1],
"aom__image_8h.html#a5267ad095a088ece3499336812503cefa9e74dcb338953bfab3101aa33ea44157":[14,0,0,5,21,14],
"aom__image_8h.html#a5267ad095a088ece3499336812503cefae01d6159bebd65c7ea0664b26a7e181a":[14,0,0,5,21,3],
"aom__image_8h.html#a570db29fbd122951235a08fe9375f6bb":[14,0,0,5,27],
"aom__image_8h.html#a5cd603aed1d6812606ed04f4533a866d":[14,0,0,5,14],
"aom__image_8h.html#a5d9e0a30df3279869dcbf537101ab131":[14,0,0,5,39],
"aom__image_8h.html#a607b37d91f75442f54223ecd85f1b6cb":[14,0,0,5,5],
"aom__image_8h.html#a6bc018ed9689367acae810bc58527081":[14,0,0,5,23],
"aom__image_8h.html#a6bc018ed9689367acae810bc58527081a06a4defb1e5d9bb1d2aad092b8656a03":[14,0,0,5,23,2],
"aom__image_8h.html#a6bc018ed9689367acae810bc58527081a0f81310501079cc1184d5265ae2c18a5":[14,0,0,5,23,6],
"aom__image_8h.html#a6bc018ed9689367acae810bc58527081a17489bf0aed544427f7c6bbe4837b212":[14,0,0,5,23,0],
"aom__image_8h.html#a6bc018ed9689367acae810bc58527081a2dea210273bc3d85af0631fd06a1066a":[14,0,0,5,23,15],
"aom__image_8h.html#a6bc018ed9689367acae810bc58527081a30661e9d9b70ffe9f51f3bdbfd02865b":[14,0,0,5,23,12],
"aom__image_8h.html#a6bc018ed9689367acae810bc58527081a34148eae7b467eece6af5c90405dde6b":[14,0,0,5,23,10],
"aom__image_8h.html#a6bc018ed9689367acae810bc58527081a3aeb0ed0afc0a92ce758f109cd05ee80":[14,0,0,5,23,11],
"aom__image_8h.html#a6bc018ed9689367acae810bc58527081a42016b6c816d7ba0e13f3805f9911043":[14,0,0,5,23,7],
"aom__image_8h.html#a6bc018ed9689367acae810bc58527081a6444a997c52f5c54044e317e195dab1d":[14,0,0,5,23,3],
"aom__image_8h.html#a6bc018ed9689367acae810bc58527081a7695b0577d3884a89c578f28f4237aee":[14,0,0,5,23,14],
"aom__image_8h.html#a6bc018ed9689367acae810bc58527081aa2140164b26b42404c376cc921ce27c5":[14,0,0,5,23,8],
"aom__image_8h.html#a6bc018ed9689367acae810bc58527081aa391f9255e4775da0120f7472b417193":[14,0,0,5,23,13],
"aom__image_8h.html#a6bc018ed9689367acae810bc58527081aa70fd9b88bc91bd0d126aaa07421c49a":[14,0,0,5,23,1],
"aom__image_8h.html#a6bc018ed9689367acae810bc58527081adf60aa79c6a68f4eb41e1095f8bf7bf6":[14,0,0,5,23,9],
"aom__image_8h.html#a6bc018ed9689367acae810bc58527081ae368663c2c2f34683b513e159c5738b9":[14,0,0,5,23,4],
"aom__image_8h.html#a6bc018ed9689367acae810bc58527081ae9107262b437659514abdcd928e977db":[14,0,0,5,23,5],
"aom__image_8h.html#a6dd7896bd2efb5eef7ce0d396836898b":[14,0,0,5,37],
"aom__image_8h.html#a7084ac01cd52ccf0b44e02dbe2467b5a":[14,0,0,5,3],
"aom__image_8h.html#a810814433692da248f4aafb32d774e1d":[14,0,0,5,38],
"aom__image_8h.html#a85eb9a862534919bc3e4bdf2d24357a2":[14,0,0,5,11],
"aom__image_8h.html#a930317c04b4bd0a660bb5e744055523c":[14,0,0,5,20],
"aom__image_8h.html#a930317c04b4bd0a660bb5e744055523ca064683ed4260fc6244af6cfc9d261c22":[14,0,0,5,20,9],
"aom__image_8h.html#a930317c04b4bd0a660bb5e744055523ca20a9cf30277260685642b4cfb4e9273b":[14,0,0,5,20,7],
"aom__image_8h.html#a930317c04b4bd0a660bb5e744055523ca377a60c48da3bdc71dccf74112a4b0f6":[14,0,0,5,20,4],
"aom__image_8h.html#a930317c04b4bd0a660bb5e744055523ca6d845490a6333fca3ac22cc1105deadd":[14,0,0,5,20,8],
"aom__image_8h.html#a930317c04b4bd0a660bb5e744055523ca89d423506e948ab7d3b98b5750b92655":[14,0,0,5,20,6],
"aom__image_8h.html#a930317c04b4bd0a660bb5e744055523cab2f75281e94ebc0f0bc728ef287cd3e8":[14,0,0,5,20,5],
"aom__image_8h.html#a930317c04b4bd0a660bb5e744055523cab75c1af1658184b1480f47ffd4c9e527":[14,0,0,5,20,0],
"aom__image_8h.html#a930317c04b4bd0a660bb5e744055523cab9b93d397dedbdd6bfafec84d1f8f0f5":[14,0,0,5,20,10],
"aom__image_8h.html#a930317c04b4bd0a660bb5e744055523cabd778a3d697463e89d12a1117f417b60":[14,0,0,5,20,2],
"aom__image_8h.html#a930317c04b4bd0a660bb5e744055523cad28244100a2754409f285b77a3db90a0":[14,0,0,5,20,1],
"aom__image_8h.html#a930317c04b4bd0a660bb5e744055523caf066b272547a880cd302c50cdcb6e76e":[14,0,0,5,20,3],
"aom__image_8h.html#a99f0bfbfad706eb1d7f611680fe6b69d":[14,0,0,5,13],
"aom__image_8h.html#aaa01a0597cfdf4f98c65e76615bb8f37":[14,0,0,5,10],
"aom__image_8h.html#ab21e8d805074aa2963fa1bfaeff41bc2":[14,0,0,5,18],
"aom__image_8h.html#ab87684a93e3da97bd6223d1e46876848":[14,0,0,5,34],
"aom__image_8h.html#ab965d61dd35b501760b76a2fa9b46fd6":[14,0,0,5,40],
"aom__image_8h.html#ac4dfa64dcf35f90c1efcfc8c4f2a0c31":[14,0,0,5,35],
"aom__image_8h.html#acb82d93a9a9f88ec2361b61a8cac1597":[14,0,0,5,24],
"aom__image_8h.html#acb82d93a9a9f88ec2361b61a8cac1597a42efbf144c6cdfbd8d230abba62573d2":[14,0,0,5,24,0],
"aom__image_8h.html#acb82d93a9a9f88ec2361b61a8cac1597a477797bb12706b2bfbfcf400699e2945":[14,0,0,5,24,1],
"aom__image_8h.html#ad3f7408993a6b35b3351eb706dcc4884":[14,0,0,5,36],
"aom__image_8h.html#adfb2ea2e110ee42e38370868b64bf232":[14,0,0,5,33],
"aom__image_8h.html#ae3c901d141136eab9c1add5dfa7bb321":[14,0,0,5,4],
"aom__image_8h.html#ae894917c25c4d0e7d848d7d1922f5d96":[14,0,0,5,19],
"aom__image_8h.html#aeb211e5184687f7e10d7c5bed4dcfdcd":[14,0,0,5,29],
"aom__image_8h.html#afff22f7f3eb9409c5b678d1962f110a8":[14,0,0,5,32],
"aom__image_8h_source.html":[14,0,0,5],
"aom__integer_8h_source.html":[14,0,0,6],
"aomcx_8h.html":[14,0,0,7],
"aomcx_8h_source.html":[14,0,0,7],
"aomdx_8h.html":[14,0,0,8],
"aomdx_8h_source.html":[14,0,0,8],
"aq__cyclicrefresh_8h_source.html":[14,0,2,2,0],
"av1__common__int_8h_source.html":[14,0,2,0,0],
"av1__loopfilter_8h_source.html":[14,0,2,0,1],
"bitstream_8h_source.html":[14,0,2,2,1],
"block_8h.html":[14,0,2,2,2],
"block_8h.html#a602ec0e36e0a86c78c15fe547c275e1f":[14,0,2,2,2,29],
"block_8h.html#a6e06ec17c5b54de9fd8d829fb2a305b7":[14,0,2,2,2,32],
"block_8h.html#a73de00e232811ea3f0290dcc425f86d5":[14,0,2,2,2,27],
"block_8h.html#a8c18014b69f341bf169c4a5656ee2978":[14,0,2,2,2,30],
"block_8h.html#aa775a8f85de55be3f4c2e39285d706c9":[14,0,2,2,2,33],
"block_8h.html#aaaf8a99ac7b3d643d9b95ea1da93f6c2":[14,0,2,2,2,34],
"block_8h.html#ab657b1844dfce1e763e658761bb0952c":[14,0,2,2,2,28],
"block_8h.html#ad4666c85680e16e181fe9b46c1957274":[14,0,2,2,2,31],
"block_8h.html#ae0a195ea38f0a04ad9a9d6d7ed5bb754":[14,0,2,2,2,26],
"block_8h_source.html":[14,0,2,2,2],
"blockd_8h_source.html":[14,0,2,0,2],
"cdef_8h_source.html":[14,0,2,0,3],
"changelog.html":[4],
"decoder_8h_source.html":[14,0,2,1,0],
"decoder_guide.html":[7],
"deprecated.html":[11],
"dir_0064b064d6a7a5d5fcf1be5043b8681b.html":[14,0,2,2],
"dir_03093512ba12f48a62bf733dcbb900e4.html":[14,0,1],
"dir_7f39fd648ffc5ea11a4f797c0913a431.html":[14,0,2],
"dir_8d0893b0137b73850aafe61c551d8e50.html":[14,0,2,0],
"dir_92479bc02b9b8071926e43bc5a876af8.html":[14,0,2,1],
"dir_df76f8a6ece5da8c91e94a848695e7b1.html":[14,0,0],
"encode__strategy_8h.html":[14,0,2,2,3],
"encode__strategy_8h_source.html":[14,0,2,2,3],
"encoder_8h.html":[14,0,2,2,4],
"encoder_8h.html#a0207efa57c443f3ff9e157c22c532b5f":[14,0,2,2,4,39],
"encoder_8h.html#a03bce75164cb579c775759205ed26055":[14,0,2,2,4,42],
"encoder_8h.html#a03bce75164cb579c775759205ed26055a0387b2a2bbc01b142f3716c18a97fe9d":[14,0,2,2,4,42,1],
"encoder_8h.html#a03bce75164cb579c775759205ed26055a6e437058362eef3c17fc5c856202dee3":[14,0,2,2,4,42,2],
"encoder_8h.html#a03bce75164cb579c775759205ed26055a6f0f4239b7fc9f98980631093f885cc0":[14,0,2,2,4,42,3],
"encoder_8h.html#a03bce75164cb579c775759205ed26055a7ab17ad52ce554037df368d89cef2c02":[14,0,2,2,4,42,0],
"encoder_8h.html#a1abd57b3c653bb72dee5f88ba45f1cda":[14,0,2,2,4,41],
"encoder_8h.html#a246db68993252fe81c1e5a911575efb4":[14,0,2,2,4,40],
"encoder_8h.html#a371e7dff2f6e26ebcb3ac61fd872a21f":[14,0,2,2,4,37],
"encoder_8h.html#a9af93120431b9d96ca04670151ea562c":[14,0,2,2,4,38],
"encoder_8h.html#a9f8c3abfb05222c315bd3051a142c718":[14,0,2,2,4,36],
"encoder_8h.html#ae37f210917b9733abc7ca81445427d71":[14,0,2,2,4,35],
"encoder_8h_source.html":[14,0,2,2,4],
"encoder_guide.html":[8],
"encoder_guide.html#architecture_av1_structure":[8,0,1],
"encoder_guide.html#architecture_command_line":[8,1],
"encoder_guide.html#architecture_enc_1pass_lagged":[8,6,2,2],
"encoder_guide.html#architecture_enc_1pass_vbr":[8,6,2,0],
"encoder_guide.html#architecture_enc_2pass_vbr":[8,6,2,1],
"encoder_guide.html#architecture_enc_data_structures":[8,2],
"encoder_guide.html#architecture_enc_fixed_q":[8,6,4],
"encoder_guide.html#architecture_enc_frame_groups":[8,7],
"encoder_guide.html#architecture_enc_frame_groups_data":[8,7,0],
"encoder_guide.html#architecture_enc_frame_groups_groups":[8,7,1],
"encoder_guide.html#architecture_enc_frame_proc_data":[8,5,0],
"encoder_guide.html#architecture_enc_frame_proc_film":[8,5,3],
"encoder_guide.html#architecture_enc_frame_proc_ingest":[8,5,1],
"encoder_guide.html#architecture_enc_frame_proc_tf":[8,5,2],
"encoder_guide.html#architecture_enc_frame_proc_tf_algo":[8,5,2,1],
"encoder_guide.html#architecture_enc_frame_proc_tf_funcs":[8,5,2,2],
"encoder_guide.html#architecture_enc_frame_proc_tf_overview":[8,5,2,0],
"encoder_guide.html#architecture_enc_gf_length":[8,7,2],
"encoder_guide.html#architecture_enc_gf_structure":[8,7,3],
"encoder_guide.html#architecture_enc_inter_modes":[8,11],
"encoder_guide.html#architecture_enc_intra_modes":[8,10],
"encoder_guide.html#architecture_enc_kf_groups":[8,7,4],
"encoder_guide.html#architecture_enc_partitions":[8,9],
"encoder_guide.html#architecture_enc_rate_ctrl":[8,6],
"encoder_guide.html#architecture_enc_rate_ctrl_data":[8,6,0],
"encoder_guide.html#architecture_enc_rate_ctrl_options":[8,6,1],
"encoder_guide.html#architecture_enc_rc_loop":[8,6,3],
"encoder_guide.html#architecture_enc_speed_quality":[8,4]
};
